#
# spec file for package libde265
#
# Copyright (c) 2023 Packman Team <packman@links2linux.de>
# Copyright (c) 2017 Bjørn Lie, Bryne, Norway.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#

%define so_ver  0
Name:           libde265
Version:        1.0.12
Release:        1699.1.pm.12
Summary:        Open H.265 video codec implementation
License:        LGPL-3.0-only
Group:          System/Libraries
URL:            https://www.libde265.org/
Source0:        https://github.com/strukturag/libde265/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
Patch0:         libde265-disable_tools.patch
BuildRequires:  automake
BuildRequires:  c++_compiler
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
libde265 is an open source implementation of the H.265 video codec.
It is written from scratch for simplicity and efficiency. Its simple
API makes it easy to integrate it into other software.

%package -n %{name}-%{so_ver}
Summary:        Open H.265 video codec implementation - libraries
Group:          System/Libraries

%description -n %{name}-%{so_ver}
libde265 is an open source implementation of the H.265 video codec.
It is written from scratch for simplicity and efficiency. Its simple
API makes it easy to integrate it into other software.

This package contains the library files.

%package devel
Summary:        Open H.265 video codec implementation - development files
Group:          Development/Libraries/Other
Requires:       %{name}-%{so_ver} = %{version}

%description devel
libde265 is an open source implementation of the H.265 video codec.
It is written from scratch for simplicity and efficiency. Its simple
API makes it easy to integrate it into other software.

The development headers for compiling programs that use libde265
are provided by this package.

%prep
%autosetup -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
	--disable-static \
	--enable-shared \
	--disable-encoder \
	--disable-dec265 \
	--disable-sherlock265 \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{name}-%{so_ver} -p /sbin/ldconfig
%postun -n %{name}-%{so_ver} -p /sbin/ldconfig

%files -n %{name}-%{so_ver}
%license COPYING
%{_libdir}/%{name}.so.*

%files devel
%doc AUTHORS README.md
%{_includedir}/%{name}/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Wed Oct 18 2023 Bjørn Lie <zaitor@opensuse.org>
- Update to version 1.0.12:
  * Fix CVE-2023-27102
  * Fix CVE-2023-27103
* Sun Jun  4 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.11
  * fixed generation of pkgconfig file with autotools
  * fixed crashes recently detected by fuzzing
  version 1.0.10:
  * This release fixes the known CVEs below, many of them are
    actually caused by the same underlying issues that manifest
    in different ways.
    CVE-2020-21594 CVE-2020-21595 CVE-2020-21596 CVE-2020-21597
    CVE-2020-21598 CVE-2020-21599 CVE-2020-21600 CVE-2020-21601
    CVE-2020-21602 CVE-2020-21603 CVE-2020-21604 CVE-2020-21605
    CVE-2020-21606 CVE-2022-1253 CVE-2022-43236 CVE-2022-43237
    CVE-2022-43238 CVE-2022-43239 CVE-2022-43240 CVE-2022-43241
    CVE-2022-43242 CVE-2022-43243 CVE-2022-43244 CVE-2022-43245
    CVE-2022-43248 CVE-2022-43249 CVE-2022-43250 CVE-2022-43252
    CVE-2022-43253 CVE-2022-47655
* Thu Jan 19 2023 Bjørn Lie <zaitor@opensuse.org>
- Update to version 1.0.9
  * Security fixes.
* Sun Nov 29 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.0.8
  * read HDR parameters from VUI header
  * fix reading matrix_coeffs from VUI header
  version 1.0.7:
  * add API to read VUI color information from bitstream
  version 1.0.6:
  * fix race in static mutex initialization
  * fix missing headers to install in CMakeLists.txt
* Mon Apr 20 2020 zaitor@opensuse.org
- Update to version 1.0.5:
  + Fixes in the CMake build system (NOMINMAX).
  + Support stdin/stdout as input/output in dec265.
  + More input stream error checking (vps_num_hrd_parameters).
- Changes from version 1.0.4:
  + Fix decoding of monochrome streams (needed for depth images in
    heif images).
  + Improved cmake build script.
- Drop libde265-use_new_FFMPEG_enum_names.patch and
  libde265-only_export_decoder_api.patch: Fixed upstream.
- Rebase libde265-disable_tools.patch.
- Pass --disable-encoder to configure, do not build binary encoder.
* Tue May  8 2018 zaitor@opensuse.org
- Update to version 1.0.3:
  + Fixes for compiler build problems.
  + Security fixes, mainly checking for corrupted input streams.
- Add debian and upstream patches:
  + libde265-only_export_decoder_api.patch
  + libde265-disable_tools.patch
  + libde265-use_new_FFMPEG_enum_names.patch
* Thu Nov 30 2017 zaitor@opensuse.org
- Add baselibs.conf, build 32bit support for x86_64.
* Sun Nov 26 2017 zaitor@opensuse.org
- Initial packaging for openSUSE.
